pub struct CyclesCount { /* private fields */ }Expand description
Process N cycles, displayed as Hertz.
This value is user-provided and does not necessarily correspond to the CPU’s cycle frequency, so it may represent cycles of anything appropriate for the benchmarking context.
Implementations
Sourceimpl CyclesCount
impl CyclesCount
Sourcepub fn new<N>(count: N) -> CyclesCountwhere
N: CountUInt,
pub fn new<N>(count: N) -> CyclesCountwhere
N: CountUInt,
Count N cycles.